@@ -6,18 +6,18 @@ from typing import Union
 
 import numpy as np
 import pandas as pd
-from timeseriesflattener.feature_spec_objects import (
-    AnySpec,
-    PredictorSpec,
-    StaticSpec,
-    TemporalSpec,
-)
 from wasabi import Printer
 
 from psycop_feature_generation.data_checks.utils import save_df_to_pretty_html_table
 from psycop_feature_generation.loaders.flattened.local_feature_loaders import (
     load_split_predictors,
 )
+from timeseriesflattener.feature_spec_objects import (
+    PredictorSpec,
+    StaticSpec,
+    TemporalSpec,
+    _AnySpec,
+)
 
 UNICODE_HIST = {
     0: " ",
@@ -134,7 +134,7 @@ def generate_static_feature_description(series: pd.Series, predictor_spec: Stati
 
 def generate_feature_description_row(
     series: pd.Series,
-    predictor_spec: AnySpec,
+    predictor_spec: _AnySpec,
 ) -> dict:
     """Generate a row with feature description.
 
